ClientConfig class

Client module configuration.

Constructors

ClientConfig({String path = 'client', String flutterSdkVersion = '', String? flutterSdkPathWindows, String? flutterSdkPathMacos, String? flutterSdkPathLinux})
const

Properties

flutterSdkPath String?
Resolved Flutter SDK path for the current platform.
no setter
flutterSdkPathLinux String?
final
flutterSdkPathMacos String?
final
flutterSdkPathWindows String?
final
flutterSdkVersion String
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited