Project class

Project root resolution and config access.

Constructors

Project()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

clientDir String
no setter
config FxConfig
no setter
rootDir String
Locate project root by searching upward for fx.yaml.
no setter
serverDir String
no setter