Shell class
Shell command execution utilities.
Constructors
- Shell()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isPortListening(
int port) → Future< bool> - Check if a TCP port is listening on localhost.
-
run(
String executable, List< String> arguments, {String? workingDirectory, Map<String, String> ? environment}) → Future<ProcessResult> - Run a command and return the ProcessResult.
-
runInteractive(
String executable, List< String> arguments, {String? workingDirectory, Map<String, String> ? environment}) → Future<int> - Run a command with stdout/stderr inherited (interactive).