MysqlService class
Manages MySQL lifecycle for development.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
ensureDatabase(
String serverDir) → Future< void> - Ensure the database defined in server/.env exists.
-
ensureRunning(
) → Future< void> - Ensure MySQL is running, attempt to start it if not.