FxConfig class
Parsed fx.yaml configuration with sensible defaults.
Constructors
- FxConfig({required String name, ServerConfig server = const ServerConfig(), ClientConfig client = const ClientConfig(), DatabaseConfig? database})
Properties
- client → ClientConfig
-
final
- database → DatabaseConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMysql → bool
-
Whether MySQL is configured in fx.yaml.
no setter
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server → ServerConfig
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited